# History

## 0.0.4 - 2020-06-05

* Add initial version of pretrained solvers
* Reorganize ColumnMapSolver code tree
* Add REST API to access DataTracer solvers via HTTP

## 0.0.3 - 2020-05-28

* Finish Column Mapping and add tutorial
* Minor refactoring and adding docstrings
* Fix testing config

## 0.0.2 - 2020-05-26

* Curate configuration and dependencies

## 0.0.1 - 2020-05-22

First release.

Features:

* Primary Key Detection
* Foreign Key Detection
* Column Mapping
